# Welcome
Please find the full documentation on [ReadTheDocs](https://baangt.readthedocs.io)

# Further reading:
* Homepage https://baangt.org
* Blog https://baangt.org/blog

# Follow us:
* Overview, contact and blog: [https://www.baangt.org](https://www.baangt.org)
* Documentation: [https://baangt.readthedocs.io](https://baangt.readthedocs.io)
* Facebook: [https://facebook.com/baangtSoftware](https://facebook.com/baangtSoftware) 
* Instagram: [https://www.instagram.com/baangt_software/](https://www.instagram.com/baangt_software/)
* Twitter: [https://twitter.com/baangtTweets](https://twitter.com/baangtTweets)
* Medium: [https://medium.com/baangt](https://medium.com/baangt) 
* Youtube: [https://www.youtube.com/channel/UCHoFle1U6RfhsIh5i38C__A/](https://www.youtube.com/channel/UCHoFle1U6RfhsIh5i38C__A/)
* Telegram Channel: [https://t.me/baangt](https://t.me/baangt)
* Official repository for download: [https://github.com/Athos1972/baangt](https://github.com/Athos1972/baangt)
* Nightly builds: [https://gogs.earthsquad.global/Athos/baangt](https://gogs.earthsquad.global/Athos/baangt) 
* Binary repositories: [https://github.com/Athos1972/baangt-executables](https://github.com/Athos1972/baangt-executables)